<?php
$translations = array(
	'General_Locale' => 'sl_SI.UTF-8',
	'General_TranslatorName' => 'Aleksej Lazanski, Tom Merc',
	'General_TranslatorEmail' => 'alazanski@tuts23.com, tom@hupso.com',
	'General_EnglishLanguageName' => 'Slovenian',
	'General_OriginalLanguageName' => 'Slovenščina',
	'General_LayoutDirection' => 'ltr',
	'General_HelloUser' => 'Pozdravljen, %s!',
	'General_OpenSourceWebAnalytics' => 'Odprtokodna Spletna Analitika',
	'General_Dashboard' => 'Nadzorna Plošča',
	'General_DashboardForASpecificWebsite' => 'Nadzorna plošča za določeno spletno stran',
	'General_MultiSitesSummary' => 'Vse Spletne Strani',
	'General_AllWebsitesDashboard' => 'Vse nadzorne plošče spletnih strani',
	'General_SingleWebsitesDashboard' => 'Nadzorna plošča posamezne spletne strani',
	'General_API' => 'API',
	'General_Widgets' => 'Gradniki',
	'General_Settings' => 'Nastavitve',
	'General_GiveUsYourFeedback' => 'Podajte nam Povratno Informacijo!',
	'General_Unknown' => 'Neznano',
	'General_Never' => 'Nikoli',
	'General_Required' => '%s potrebno',
	'General_NotValid' => '%s ni veljaven',
	'General_NotDefined' => '%s ni definiran',
	'General_Id' => 'Id',
	'General_Error' => 'Napaka',
	'General_Warning' => 'Opozorilo',
	'General_BackToHomepage' => 'Nazaj na Piwik-ovo glavno stran',
	'General_Yes' => 'Da',
	'General_No' => 'Ne',
	'General_Delete' => 'Izbriši',
	'General_Report' => 'Poročilo',
	'General_Reports' => 'Poročila',
	'General_RelatedReport' => 'Povezano poročilo',
	'General_RelatedReports' => 'Povezana poročila',
	'General_Metric' => 'Metrika',
	'General_Metrics' => 'Metrike',
	'General_Edit' => 'Uredi',
	'General_Download' => 'Prenesi',
	'General_Upload' => 'Naloži',
	'General_Ok' => 'Ok',
	'General_Close' => 'Zapri',
	'General_Cancel' => 'Prekliči',
	'General_OrCancel' => 'ali %s Prekliči %s',
	'General_Logout' => 'Izpis',
	'General_Username' => 'Uporabniško Ime',
	'General_Description' => 'Opis',
	'General_Done' => 'Narejeno',
	'General_PoweredBy' => 'Poganja',
	'General_MetricsToPlot' => 'Metrično v spletko',
	'General_RowsToDisplay' => 'Vrst za prikaz',
	'General_MetricToPlot' => 'Metrično v spletko',
	'General_RecordsToPlot' => 'Zapisi za prikaz',
	'General_Name' => 'Ime',
	'General_Value' => 'Vrednost',
	'General_Total' => 'Skupaj',
	'General_AverageOrderValue' => 'Povprečna vrednost naročila',
	'General_PurchasedProducts' => 'Kupljeni Izdelki',
	'General_EcommerceOrders' => 'Ecommerce Naročila',
	'General_AbandonedCarts' => 'Opuščeni Vozički',
	'General_TotalRevenue' => 'Skupni izkupiček',
	'General_ProductRevenue' => 'Izkupiček izdelka',
	'General_AveragePrice' => 'Povprečna Cena',
	'General_AverageQuantity' => 'Povprečna Količina',
	'General_UniquePurchases' => 'Edinstveni Nakupi',
	'General_ProductConversionRate' => 'Stopnja konverzije izdelka',
	'General_Quantity' => 'Količina',
	'General_Price' => 'Cena',
	'General_Subtotal' => 'Vmesni seštevek',
	'General_Tax' => 'Davek',
	'General_Shipping' => 'Poštnina',
	'General_Discount' => 'Popust',
	'General_Details' => 'Podrobnosti',
	'General_Default' => 'Privzeto',
	'General_Visit' => 'Obisk',
	'General_FromReferrer' => 'od',
	'General_VisitorIP' => 'Obiskovalčev IP',
	'General_VisitorID' => 'ID Obiskovalca',
	'General_VisitType' => 'Vrsta obiskovalca',
	'General_VisitTypeExample' => 'Na primer, če želite zbrati vse obiskovalce, ki so se vrnili na spletno stran, vključno s tistimi, ki so v prejšnjih obiskih kaj kupili, bi API zahteva vsebovala %s',
	'General_DaysSinceLastVisit' => 'Dni od zadnjega obiska',
	'General_DaysSinceFirstVisit' => 'Dni od prvega obiska',
	'General_DaysSinceLastEcommerceOrder' => 'Dni od zadnjega Ecommerce naročila',
	'General_NumberOfVisits' => 'Število obiskov',
	'General_VisitConvertedGoal' => 'Obisk je spreobrnil vsaj en Cilj',
	'General_VisitConvertedGoalId' => 'Obisk je spreobrnil specifičen Id Cilja',
	'General_EcommerceVisitStatus' => 'Obiščite \'Status naročil\' na koncu obiska. Na primer, za izbiro vseh ob obiskov, ki so opravili naročilo, bi API zahtevek vseboval %s',
	'General_VisitConvertedNGoals' => 'Obisk spreobrnil %s Ciljev',
	'General_NewVisitor' => 'Nov Obiskovalec',
	'General_NewVisits' => 'Novi obiski',
	'General_ReturningVisitor' => 'Ponoven Obiskovalec',
	'General_Visitor' => 'Obiskovalec',
	'General_Date' => 'Datum',
	'General_Period' => 'Obdobje',
	'General_ChooseDate' => 'Izberite datum',
	'General_Today' => 'Danes',
	'General_Yesterday' => 'Včeraj',
	'General_CurrentWeek' => 'Trenutni Teden',
	'General_CurrentMonth' => 'Trenutni Mesec',
	'General_CurrentYear' => 'Trenutno Leto',
	'General_DateRange' => 'Datumski razpon:',
	'General_DateRangeInPeriodList' => 'Datumski razpon',
	'General_DateRangeFromTo' => 'Od %s do %s',
	'General_ApplyDateRange' => 'Uveljavi Datumski Razpon',
	'General_InvalidDateRange_js' => 'Neveljaven Datumski Razpon. Prosimo, Poskusite Znova',
	'General_DateRangeFrom_js' => 'Od',
	'General_DateRangeTo_js' => 'Za',
	'General_LastDaysShort' => 'Zadnjih %s dni',
	'General_PreviousDaysShort' => 'Prejšnjih %s dni',
	'General_PreviousDays' => 'Prejšnjih %s dni (brez današnjega dne)',
	'General_LastDays' => 'Zadnjih %s dni (vklj. z današ. dnem)',
	'General_LoadingData' => 'Nalagam podatke...',
	'General_Loading_js' => 'Nalagam...',
	'General_GoTo' => 'Pojdi na %s',
	'General_Next' => 'Naslednji',
	'General_Previous' => 'Prejšnji',
	'General_First' => 'Prvi',
	'General_Search' => 'Išči',
	'General_Others' => 'Ostali',
	'General_Table' => 'Tabela',
	'General_Piechart' => 'Kolačni diagram',
	'General_TagCloud' => 'Oblak z etiketami',
	'General_VBarGraph' => 'Stolpični Diagram',
	'General_View' => 'Ogled',
	'General_OpenInNewWindow_js' => 'Odpri v novem oknu',
	'General_SaveImageOnYourComputer_js' => 'Za shranitev te slike na vaš računalnik, kliknite z desno tipko miške na sliko ter izberite "Shrani sliko kot"',
	'General_Refresh' => 'Osveži stran',
	'General_Visitors' => 'Obiskovalci',
	'General_ExportThisReport' => 'Izvoti to razpredelnico v drugih formatih',
	'General_ExportAsImage_js' => 'Izvozi kot Sliko',
	'General_Export' => 'Izvozi',
	'General_ParameterMustIntegerBetween' => 'Parameter %s mora biti celo število med %s in %s.',
	'General_YourChangesHaveBeenSaved' => 'Vaše spremembe so bile shranjene.',
	'General_ErrorRequest' => 'Opa... Med zahtevo je prišlo do napake. Prosimo, poskusite znova.',
	'General_ColumnNbUniqVisitors' => 'Edinstveni Obiskovalci',
	'General_ColumnNbUniqVisitorsDocumentation' => 'Število nepodvojenih obiskovalcev, prihajujočih na vašo spletno stran. V primeru, da obiskovalec spletno stran obišče večkrat v enem dnevu, se to šteje le enkrat.',
	'General_ColumnNbVisits' => 'Obiskov',
	'General_ColumnNbVisitsDocumentation' => 'V primeru da pride obiskovalec na vašo spletno stran prvič, ali pa je njegov obisk daljši od 30 minut, se bo to štelo kot novi obisk.',
	'General_ColumnPercentageVisits' => '% Obiskov',
	'General_ColumnNbActions' => 'Dejanj',
	'General_ColumnNbActionsDocumentation' => 'Število akcij obiskovalcev. Akcije so lahko prikazi strani, prenosi ali izhodi preko zunanjih povezav.',
	'General_NbActions' => 'Šttevilo Dejanj',
	'General_ColumnMaxActions' => 'Maksimalno dejanj v enem obisku',
	'General_ColumnSumVisitLength' => 'Skupni čas, ki so ga porabili obiskovalci (v sekundah)',
	'General_ColumnLabel' => 'Oznaka',
	'General_ColumnConversionRate' => 'Pretvorbeno Razmerje',
	'General_ColumnConversionRateDocumentation' => 'Procent obiskov, ki so sprožili spreobrnitev cilja.',
	'General_ColumnActionsPerVisit' => 'Dejanj na Obisk',
	'General_ColumnActionsPerVisitDocumentation' => 'Povprečno število dejanj (ogledov strani, prenosov ali izhodnih povezav), ki so bila izvedena med obiskom.',
	'General_VisitDuration' => 'Povpr. Trajanje Obiska (v sekundah)',
	'General_ColumnAvgTimeOnSite' => 'Povpr. Čas na Spletni Strani',
	'General_ColumnAvgTimeOnSiteDocumentation' => 'Povprečno trajanje obiska.',
	'General_ColumnVisitDuration' => 'Trajanje Obiska (v sekundah)',
	'General_ColumnBounceRate' => 'Odbojno Razmerje',
	'General_ColumnBounceRateDocumentation' => 'Delež obiskov, ki je vseboval zgolj en sam ogled strani. To pomeni, da je obiskovalec zapustil spletno stran direktno z vhodne strani.',
	'General_ColumnBounceRateForPageDocumentation' => 'Delež obiskov, ki se tako začeli, kot tudi končali na tej strani.',
	'General_ColumnPageBounceRateDocumentation' => 'Delež obiskov, ki so se začeli na tej strani, a so nemudoma zapustili spletno stran.',
	'General_ColumnExitRate' => 'Izhodno Razmerje',
	'General_ColumnExitRateDocumentation' => 'Delež obiskov, ki so zapustili spletno stran po ogledu te strani.',
	'General_ColumnPageviews' => 'Ogledov strani',
	'General_ColumnPageviewsDocumentation' => 'Število, kolikokrat je bila ta stran obiskana.',
	'General_ColumnUniquePageviews' => 'Edinstvenih Ogledov Strani',
	'General_ColumnUniquePageviewsDocumentation' => 'Število obiskov, ki so vključevali to stran. V primeru, da je bila stran ogledana večkrat, se to šteje kot le-en ogled.',
	'General_ColumnBounces' => 'Odbojev',
	'General_ColumnBouncesDocumentation' => 'Število obiskov, ki so se začeli in končali na tej strani. To pomeni, da je obiskovalec odšel po ogledu ene same strani.',
	'General_ColumnUniqueEntrances' => 'Edinstveni vhodi',
	'General_ColumnEntrances' => 'Vhodov',
	'General_ColumnEntrancesDocumentation' => 'Število obiskov, ki so se začeli na tej strani.',
	'General_ColumnExits' => 'Izhodov',
	'General_ColumnUniqueExits' => 'Edinstveni izhodi',
	'General_ColumnExitsDocumentation' => 'Število obiskov, ki so se zaključili na tej strani.',
	'General_ColumnAverageTimeOnPage' => 'Povpr. čas na strani',
	'General_TimeOnPage' => 'Čas na strani',
	'General_ColumnAverageTimeOnPageDocumentation' => 'Povprečen čas, ki so ga obiskovalci porabili na tej strani (samo na strani, ne na celotni spletni strani).',
	'General_ColumnValuePerVisit' => 'Vrednost na Obisk',
	'General_ColumnVisitsWithConversions' => 'Obiski s Spreobrnitvami',
	'General_VisitsWith' => 'Obiski z/s %s',
	'General_YearsDays' => '%1$s let %2$s dni',
	'General_DaysHours' => '%1$s dni %2$s ur',
	'General_HoursMinutes' => '%1$s ur %2$s min',
	'General_MinutesSeconds' => '%1$s min %2$ss',
	'General_Seconds' => '%ss',
	'General_Save' => 'Shrani',
	'General_Faq' => 'FAQ',
	'General_ForExampleShort' => 'npr.',
	'General_YouMustBeLoggedIn' => 'Za uporabo te funkcije morate biti vpisani.',
	'General_Website' => 'Spletna stran',
	'General_GeneralSettings' => 'Splošne Nastavitve',
	'General_AllowPiwikArchivingToTriggerBrowser' => 'Dovoli, da se akitivira Piwik arhiviranje, ko se poročila ogledujejo v brskalniku.',
	'General_ArchivingInlineHelp' => 'Za srednje velike in velike spletne strani izklopite arhiviranje preko spletnega brskalnika. Namesto tega vam priporočamo, da nastavite "cron job" tako, da bodo poročila ustvarjena vsako uro.',
	'General_ArchivingTriggerDescription' => 'Priporočamo za večje namestitve. %sNastavite "cron job"%s za avtomatsko procesiranje.',
	'General_SeeTheOfficialDocumentationForMoreInformation' => 'Za več informacij, si oglejte %suradno dokumentacijo%s.',
	'General_ReportsContainingTodayWillBeProcessedAtMostEvery' => 'Današnja poročila (ali kak drug časovni razpon, ki vključuje današnji dan) bodo procesirana vsakih',
	'General_NSeconds' => '%s sekund',
	'General_SmallTrafficYouCanLeaveDefault' => 'Za manjše spletne strani lahko pustite privzetih %s sekund in dostopate do poročil v realnem času.',
	'General_MediumToHighTrafficItIsRecommendedTo' => 'Za srednje velike in velike spletne strani vam priporočamo, da procesirate poročila največ na pol ure (%s sekund) ali na eno uro (%s sekund).',
	'General_RequiresFlash' => 'Za prikazovanje Grafov v Piwik-u potrebujete Flash',
	'General_GraphHelp' => 'Več informacij o prikazovanju Grafov v Piwik-u.',
	'General_NoDataForGraph' => 'Nobenih podatkov za ta graf.',
	'General_DataForThisGraphHasBeenPurged' => 'Podatki za ta graf so stari več kot %s mesecev in so bili izbrisani.',
	'General_NoDataForTagCloud' => 'Ni podatkov za oblaček z etiketami',
	'General_DataForThisTagCloudHasBeenPurged' => 'Podatki za ta oblak oznak so stari več kot %s mesecev in so bili izbrisani.',
	'General_DisplaySimpleTable' => 'Prikaži preprosto tabelo',
	'General_DisplayTableWithMoreMetrics' => 'Prikaži podrobnejšo tabelo',
	'General_DisplayTableWithGoalMetrics' => 'Prikaži tabelo z metričnimi cilji',
	'General_YouAreViewingDemoShortMessage' => 'Trenutno si ogledujete Piwik v demo načinu',
	'General_YouAreCurrentlyUsing' => 'Trenutno uporabljate Piwik %s.',
	'General_DownloadFullVersion' => '%1$sPrenesite%2$s celotno verzijo! Oglejte si %3$s',
	'General_NewUpdatePiwikX' => 'Nova Posodobitev: Piwik %s',
	'General_AboutPiwikX' => 'O Piwik %s',
	'General_PiwikXIsAvailablePleaseUpdateNow' => 'Piwik %1$s je na voljo. %2$sProsimo posodobite ga zdaj!ow!%3$s (oglejte si %4$sspremembe%5$s).',
	'General_PiwikXIsAvailablePleaseNotifyPiwikAdmin' => '%s je na voljo. Prosimo, da o tem obvestite skrbnika strani.',
	'General_NewReportsWillBeProcessedByCron' => 'Ko se arhiviranje ne sproži preko brskalnika, bodo nova poročila generirana preko crontaba.',
	'General_ReportsWillBeProcessedAtMostEveryHour' => 'Poročila bodo torej generirana največ vsako uro.',
	'General_IfArchivingIsFastYouCanSetupCronRunMoreOften' => 'Če bo arhiviranje na vašem sistemu hitro, lahko popravite crontab, tako da se bo arhiviranje zagnalo pogosteje.',
	'General_BackToPiwik' => 'Nazaj na Piwik',
	'General_ClickHere' => 'Za več informacij, kliknite tu.',
	'General_ShortMonth_1' => 'Jan',
	'General_ShortMonth_2' => 'Feb',
	'General_ShortMonth_3' => 'Mar',
	'General_ShortMonth_4' => 'Apr',
	'General_ShortMonth_5' => 'Maj',
	'General_ShortMonth_6' => 'Jun',
	'General_ShortMonth_7' => 'Jul',
	'General_ShortMonth_8' => 'Avg',
	'General_ShortMonth_9' => 'Sep',
	'General_ShortMonth_10' => 'Okt',
	'General_ShortMonth_11' => 'Nov',
	'General_ShortMonth_12' => 'Dec',
	'General_LongMonth_1' => 'Januar',
	'General_LongMonth_2' => 'Februar',
	'General_LongMonth_3' => 'Marec',
	'General_LongMonth_4' => 'April',
	'General_LongMonth_5' => 'Maj',
	'General_LongMonth_6' => 'Junij',
	'General_LongMonth_7' => 'Julij',
	'General_LongMonth_8' => 'Avgust',
	'General_LongMonth_9' => 'September',
	'General_LongMonth_10' => 'Oktober',
	'General_LongMonth_11' => 'November',
	'General_LongMonth_12' => 'December',
	'General_ShortDay_1' => 'Pon',
	'General_ShortDay_2' => 'Tor',
	'General_ShortDay_3' => 'Sre',
	'General_ShortDay_4' => 'Čet',
	'General_ShortDay_5' => 'Pet',
	'General_ShortDay_6' => 'Sob',
	'General_ShortDay_7' => 'Ned',
	'General_LongDay_1' => 'Ponedeljek',
	'General_LongDay_2' => 'Torek',
	'General_LongDay_3' => 'Sreda',
	'General_LongDay_4' => 'Četrtek',
	'General_LongDay_5' => 'Petek',
	'General_LongDay_6' => 'Sobota',
	'General_LongDay_7' => 'Nedelja',
	'General_Daily' => 'Dnevno',
	'General_Weekly' => 'Tedensko',
	'General_Monthly' => 'Mesečno',
	'General_DailyReports' => 'Dnevna poročila',
	'General_WeeklyReports' => 'Tedenska poročila',
	'General_MonthlyReports' => 'Mesečna poročila',
	'General_YearlyReports' => 'Letna poročila',
	'General_RangeReports' => 'Časovni razpon po meri',
	'General_ConfigFileIsNotWritable' => 'Piwik-ova konfiguracijska datoteka %s ni zapisljiva, zato nekaterih vaših sprememb ni bilo mogoče shraniti. %s Prosimo, da spremenite dovoljenja konfiguracijske datoteke tako, da bo zapisljiva.',
	'General_ExceptionDatabaseVersion' => 'Vaša %1$s verzija je %2$s, vendar Piwik potrebuje vsaj %3$s.',
	'General_ExceptionIncompatibleClientServerVersions' => 'Vaša %1$s različica odjemalca je %2$s, ki je nezdružljiva s strežniško različico %3$s.',
	'General_ExceptionMissingFile' => 'Manjkajoča datoteka: %s',
	'General_ExceptionFilesizeMismatch' => 'Velikost datoteke se ne ujema: %1$s (pričakovana dolžina: %2$s, najdeno: %3$s)',
	'General_ExceptionFileIntegrity' => 'Preverjanje integritete ni bilo uspešno: %s',
	'General_ExceptionNonceMismatch' => 'Ne morem preveriti varnostnega žetona na tem obrazcu.',
	'General_PleaseSpecifyValue' => 'Prosimo, navedite vrednost za "%s"',
	'General_ExceptionMethodNotFound' => 'Metoda \'%s\' ne obstaja ali ni na voljo v modulu \'%s\'.',
	'General_ExceptionInvalidRendererFormat' => 'Oblika prikaza \'%s\' ni pravilna. Namesto tega poskusite kaj od tega: %s.',
	'General_ExceptionInvalidReportRendererFormat' => 'Oblika poročila \'%s\' ni pravilna. Namesto tega poskusite kaj od tega: %s.',
	'General_ExceptionInvalidStaticGraphType' => 'Tip statičnega grafa \'%s\' ni pravilen. Namesto tega poskusite kaj od tega: %s.',
	'General_ExceptionInvalidAggregateReportsFormat' => 'Oblika skupnega poročila \'%s\' ni pravilna. Namesto tega poskusite kaj od tega: %s.',
	'General_ExceptionInvalidPeriod' => 'Obdobje \'%s\' ni podprto. Namesto tega poskusite kaj od tega: %s.',
	'General_ExceptionInvalidDateRange' => '\'%s\' ni pravilen datumski razpon. Moral bi imeti naslednjo obliko: %s.',
	'General_ExceptionGoalNotFound' => 'Cilja z id = %s ni mogoče najti.',
	'General_ExceptionUndeletableFile' => '%s ni možno izbrisati.',
	'General_ExceptionPrivilege' => 'Ne morete dostopati do tega vira, saj je za to potreben %s dostop.',
	'General_ExceptionPrivilegeAtLeastOneWebsite' => 'Ne morete dostopati do tega vira, ker potrebujete %s dostop za vsaj eno spletno stran.',
	'General_ExceptionPrivilegeAccessWebsite' => 'Ne morete dostopati do tega vira, ker potrebujete %s dostop za spletno stran z id = %d.',
	'General_ExceptionInvalidArchiveTimeToLive' => '"Today archive time to live" mora biti število sekund več kot nič.',
	'General_ExceptionConfigurationFileNotFound' => 'Konfiguracijska datoteka {%s} ni bila najdena.',
	'General_ExceptionUnreadableFileDisabledMethod' => 'Konfiguracijske datoteke {%s} ni bilo mogoče prebrati. Možno je, da je vaš gostitelj onemogočil %s.',
	'General_ExceptionInvalidToken' => 'Žeton ni veljaven.',
	'General_ExceptionInvalidDateFormat' => 'Oblika datuma mora biti: %s ali katerakoli ključna beseda, podprta v funkciji %s (oglejte si %s za več informacij)',
	'General_ExceptionLanguageFileNotFound' => 'Jezikovne datoteke "%s" ni bilo mogoče najti.',
	'General_ExceptionUnableToStartSession' => 'Ne morem začeti seje.',
	'General_ExceptionCheckUserIsSuperUserOrTheUser' => 'Uporabnik mora biti administrator ali uporabnik \'%s\'.',
	'General_WarningFileIntegritySkipped' => 'Zaznano je bilo razvojno okolje. Pregled integritete datotek je bil preskočen.',
	'General_WarningFileIntegrityNoManifest' => 'Pregleda integritete datotek ni bilo mogoče izvesti, saj manjka manifest.inc.php.',
	'General_WarningFileIntegrityNoMd5file' => 'Ne morem preveriti integritete datoteke, ker manjka funkcija md5_file().',
	'General_FileIntegrityWarningExplanation' => 'Preverjanje integritete ni uspelo in je javilo neke napake. Vzrok za to so verjetno nekatere Piwik datoteke, ki so se delno ali narobe prenesle. Ponovno morate prenesti vse Piwik datoteke na strežnik v BINARY načinu in osvežiti to stran, tako da ne bo več vidne nobene napake.',
	'General_UseSMTPServerForEmail' => 'Uporabljaj SMTP strežnik za e-pošto',
	'General_SmtpServerAddress' => 'Naslov SMTP strežnika',
	'General_SmtpPort' => 'SMTP Vrata',
	'General_AuthenticationMethodSmtp' => 'Metoda potrditve verodostojnosti za SMTP',
	'General_SmtpUsername' => 'SMTP uporabniško ime',
	'General_SmtpPassword' => 'SMTP geslo',
	'General_SmtpEncryption' => 'SMTP enkripcija',
	'General_SelectYesIfYouWantToSendEmailsViaServer' => 'Izberite "da" če želite pošiljanje emaila preko strežnika, namesto preko lokalne mail funkcije',
	'General_OptionalSmtpPort' => 'Neobvezno. Privzeto je 25 za nekriptiran prometi in za TLS SMTP. 465 za SSL SMTP.',
	'General_OnlyUsedIfUserPwdIsSet' => 'Uporabljeno samo če je nastavljeno uporabniško ime in geslo. Če niste prepričani katero metodo bi uporabili, prosmo kontaktirajte vašega ponudnika.',
	'General_OnlyEnterIfRequired' => 'Uporabniško ime vnesite le, če to zahteva vaš SMTP strežnik.',
	'General_OnlyEnterIfRequiredPassword' => 'Geslo vnesite le, če to zahteva vaš SMTP strežnik.',
	'General_WarningPasswordStored' => '%sPozor:%s To geslo bo shranjeno v config datoteki. Tako bo vidna vsem, ki imajo dostop do te datoteke.',
	'General_EncryptedSmtpTransport' => 'Vnesite nivo enkripcije, ki jo uporablja vaš SMTP strežnik.',
	'General_InvalidResponse' => 'Prejeti podatki niso pravilni.',
	'General_ChooseLanguage' => 'Izberite jezik',
	'General_ChoosePeriod' => 'Izberite obdobje',
	'General_ChooseWebsite' => 'Izberite spletno stran',
	'General_Language' => 'Jezik',
	'General_PleaseUpdatePiwik' => 'Prosimo, da posodobite Piwik',
	'General_RequestTimedOut' => 'Podatkovna zahteva za %s je pretekla. Prosimo, poskusite znova.',
	'General_UsePlusMinusIconsDocumentation' => 'Uporabite plus in minus ikoni na levi za navigacijo.',
	'General_BrokenDownReportDocumentation' => 'Razčlenjen je na različna poročila, ki so prikazana z grafi na dnu strani. grafe lahko povečate s klikov na poročilo, ki bi si ga radi ogledali.',
	'General_ChangeTagCloudView' => 'Zavedajte se, da si lahko ogledate proočila na drugačne načine kot oblak oznak. Za spremembo uporabite izbire na dnu poročila.',
	'General_Recommended' => '(priporočano)',
	'General_NotRecommended' => '(ni priporočljivo)',
	'General_Goal' => 'Cilj',
	'General_Outlink' => 'Izhodna povezaba',
	'General_Help' => 'Pomoč',
	'General_DailySum' => 'dnevna vsota',
	'General_AfterEntry' => 'po tukajšnjem vstopu',
	'General_Metadata' => 'Metadata',
	'General_OneVisit' => '1 obisk',
	'General_NVisits' => '%s obiskov',
	'General_OneDay' => '1 dan',
	'General_NDays' => '%s dni',
	'General_MainMetrics' => 'Glavna meterika',
	'General_Mobile' => 'Mobilno',
	'General_Desktop' => 'Namizno',
	'General_Rows' => 'Vrstice',
	'General_GeneralInformation' => 'Splošne informacije',
	'General_ReportGeneratedFrom' => 'To poročilo je bilo ustvarjeno s podatki iz %s.',
	'Actions_PluginDescription' => 'Poročila o prikazih strani, izhodih preko zunanjih povezav in prenosih. Sledenje prenosom in izhodom preko zunanjih povezav je samodejno.',
	'Actions_Actions' => 'Dejanja',
	'Actions_SubmenuPages' => 'Strani',
	'Actions_SubmenuPagesEntry' => 'Vstopne strani',
	'Actions_WidgetPagesEntry' => 'Vstopne strani',
	'Actions_SubmenuPagesExit' => 'Izhodne strani',
	'Actions_WidgetPagesExit' => 'Izhodne strani',
	'Actions_EntryPageTitles' => 'Nazivi vhodnih strani',
	'Actions_WidgetEntryPageTitles' => 'Naslovi vstopnih strani',
	'Actions_ExitPageTitles' => 'Nazivi izhodnih strani',
	'Actions_WidgetExitPageTitles' => 'Naslovi izhodnih strani',
	'Actions_SubmenuPageTitles' => 'Naslovi strani',
	'Actions_WidgetPageTitles' => 'Naslovi strani',
	'Actions_PageUrls' => 'URL-ji strani',
	'Actions_SubmenuOutlinks' => 'Izhodne povezave',
	'Actions_SubmenuDownloads' => 'Prenosi',
	'Actions_PagesReportDocumentation' => 'To poročilo vsebuje informacije o URL-jih strani, ki so bile obiskane. %s Tabela je hierarhično organizirana. URL-ji so prikazani kot struktura mape.',
	'Actions_PageTitlesReportDocumentation' => 'To poročilo vsebuje informacije o nazivih strani, ki so bile obiskane. %s Naziv strani je HTML oznaka %s Oznaka, ki jo večina brskalnikov prikaže v nazivu okna.',
	'Actions_OutlinksReportDocumentation' => 'To poročilo prikazuje hierarhični seznam URL-jev zunanjih povezav na katere so uporabniki kliknili.',
	'Actions_OutlinkDocumentation' => 'Zunanja povezava je povezava, ki vodi obiskovalca stran od vaše splete strani (na drugo domeno).',
	'Actions_DownloadsReportDocumentation' => 'V tem poročilu lahko visite, katere datoteke so prenesli vaši uporabniki. %s Piwik šteje vse klike na povezavo za prenos. Piwik ne ve ali je bila datoteka uspešno prenesena.',
	'Actions_ColumnClicks' => 'Kliki',
	'Actions_ColumnClicksDocumentation' => 'Število klikov na to povezavo.',
	'Actions_ColumnUniqueClicks' => 'Edinstveni Kliki',
	'Actions_ColumnUniqueClicksDocumentation' => 'Število obiskov, ki so vsebovali klik na to povezavo. Če je bilo klikov na isto povezavo več v istem obisku, se to šteje kot en sam klik.',
	'Actions_ColumnDownloads' => 'Prenosi',
	'Actions_ColumnUniqueDownloads' => 'Edinstveni Prenosi',
	'Actions_ColumnOutlinks' => 'Izhodne povezave',
	'Actions_ColumnUniqueOutlinks' => 'Edinstvene izhodne povezave',
	'Actions_ColumnPageName' => 'Ime Spletne Strani',
	'Actions_ColumnPageURL' => 'URL Spletne Strani',
	'Actions_ColumnClickedURL' => 'Kliknjeni URL-ju',
	'Actions_ColumnDownloadURL' => 'URL za prenos',
	'Actions_ColumnEntryPageURL' => 'URL vstopne strani',
	'Actions_ColumnEntryPageTitle' => 'Naslov vstopne strani',
	'Actions_ColumnExitPageURL' => 'URL izhodne strani',
	'Actions_ColumnExitPageTitle' => 'Naslov izhodne strani',
	'Actions_EntryPagesReportDocumentation' => 'To poročilo vsebuje informacije o vhodnih straneh, ki so bile obiskane v izbranem časovnem obdobju. Vhodna stran je prva stran, ki si jo je obiskovalec ogledal med svojim obiskom. %s Vhodni URL naslovi so prikazani kot struktura mape.',
	'Actions_EntryPageTitlesReportDocumentation' => 'To poročilo vsebuje informacije o nazivih vhodnih strani, ki so bile obiskane v izbranem časovnam obdobju.',
	'Actions_ExitPageTitlesReportDocumentation' => 'To poročilo vsebuje informacije o nazivih izhodnih strani, ki so bile obiskane v izbranem časovnam obdobju.',
	'AnonymizeIP_PluginDescription' => 'Anonimiziraj zadnji bajt IP naslova obiskovalca, da se s tem izpolnijo zahteve lokalnih zakonov/smernic o zasebnosti.',
	'API_PluginDescription' => 'Vsi podatki v Piwiku so na voljo preko prepreostega API vmesnika. Ta vtičnik je vstopna točka spletne storitve, ki jo lahko pokličete, če želite svoje podatke preko xml, json, php, csv, itd.',
	'API_QuickDocumentationTitle' => 'API hitra dokumentacija',
	'API_GenerateVisits' => 'Če nimate današnjih podatkov, potem lahko najprej ustvarite nekaj podatkov s %s vtičnikom. Vtičnik %s lahko omogočite in nato kliknete na \'Visitor Generator\' meni v Piwik administraciji.',
	'API_MoreInformation' => 'Za več informacij o Piwik API-ju, si oglejte %sNavodila za uporabo Piwik API-ja %s in %s Piwik API Reference %s.',
	'API_UserAuthentication' => 'Overitev uporabnika',
	'API_UsingTokenAuth' => 'Če želite %s zahtevati podatke preko skripte, crontaba, itd. %s potem morate dodati parameter %s v URL API klica za overitev.',
	'API_KeepTokenSecret' => 'Ta žeton je skriven, kot vaše uporabniško ime in geslo, %s ne delite ga z drugimi %s!',
	'API_LoadedAPIs' => 'Uspešno naloženih %s API-jev',
	'CoreAdminHome_PluginDescription' => 'Administrativno okolje Piwik.',
	'CoreAdminHome_MenuGeneralSettings' => 'Splošne nastavitve',
	'CoreAdminHome_Administration' => 'Administracija',
	'CoreAdminHome_EmailServerSettings' => 'Nastavitev strežnika za email',
	'CoreAdminHome_OptOutForYourVisitors' => '\'Opt-out\' za vaše obiskovalce',
	'CoreAdminHome_OptOutExplanation' => 'Piwik želi zagotoviti zasebnost na internetu. Če želite svojim obiskovalcem omogočiti \'opt-out\' iz Piwik spletne analitike, potem lahko dodate naslednjo HTML kodo na vašo spletno stran, npr. na stran \'Varovanje zasebnosti\'.',
	'CoreAdminHome_YouAreOptedIn' => 'Trenutno ste pridruženi.',
	'CoreAdminHome_YouAreOptedOut' => 'Trenutno niste pridruženi.',
	'CoreAdminHome_ClickHereToOptOut' => 'Kliknite tu, če želite odstopiti.',
	'CoreAdminHome_ClickHereToOptIn' => 'Kliknite tu za pristop',
	'CoreAdminHome_BrandingSettings' => 'Nastavitve znamke',
	'CoreAdminHome_CustomLogoHelpText' => 'Piwik-ov logo lahko prilagodite po vaših željah. Spremembe bodo vidne tako v uporabniškem vmesniku, kot v email poročilih.',
	'CoreAdminHome_UseCustomLogo' => 'Uporabi poseben logo',
	'CoreAdminHome_LogoUpload' => 'Izberite Logo za nalaganje',
	'PrivacyManager_TeaserHeadline' => 'Nastavitve zasebnosti',
	'PrivacyManager_DeleteLogInfo' => 'Dnevniki iz sledečih tabel bodo izbrizani: %s',
	'PrivacyManager_UseDeleteLog' => 'Redno izbriši stare dnevnike obiskov iz podatkovne baze',
	'PrivacyManager_DeleteLogsOlderThan' => 'Izbriši dnevnike, starejše od',
	'PrivacyManager_DeleteMaxRowsNoLimit' => 'brez omejitve',
	'PrivacyManager_LastDelete' => 'Zadnji izbris je bil',
	'PrivacyManager_NextDelete' => 'Naslednji izbris je predviden',
	'PrivacyManager_ClickHereSettings' => 'Kliknite tu za dostop do %s nastavitev.',
	'PrivacyManager_LeastDaysInput' => 'Prosimo, navedite število dni, večje od %s.',
	'CoreHome_NoPrivilegesAskPiwikAdmin' => 'Vpisani ste kot \'%s\', vendar v Piwik-u nimate nastavljenih nobenih pooblastil. %s Poprosite vašega Piwik administratorja (klik za email)%s naj vam da pooblastila za ogled določene(ih) strani.',
	'CoreHome_ThereIsNoDataForThisReport' => 'Za to poročilo ni podatkov.',
	'CoreHome_CategoryNoData' => 'V tej kategoriji ni podatkov. Poizkusite "Vključiti celotno populacijo".',
	'CoreHome_ShowJSCode' => 'Prikaži JavaScript kodo za vstavljanje',
	'CoreHome_Default_js' => 'privzeto',
	'CoreHome_PageOf_js' => '%1$s od %2$s',
	'CoreHome_PeriodDay' => 'Dan',
	'CoreHome_PeriodWeek' => 'Teden',
	'CoreHome_PeriodMonth' => 'Mesec',
	'CoreHome_PeriodYear' => 'Leto',
	'CoreHome_PeriodDays' => 'dni',
	'CoreHome_PeriodWeeks' => 'tednov',
	'CoreHome_PeriodMonths' => 'mesecev',
	'CoreHome_PeriodYears' => 'let',
	'CoreHome_DaySu_js' => 'Ne',
	'CoreHome_DayMo_js' => 'Po',
	'CoreHome_DayTu_js' => 'To',
	'CoreHome_DayWe_js' => 'Sr',
	'CoreHome_DayTh_js' => 'Če',
	'CoreHome_DayFr_js' => 'Pe',
	'CoreHome_DaySa_js' => 'Su',
	'CoreHome_ShortDay_1_js' => 'Ned',
	'CoreHome_ShortDay_2_js' => 'Pon',
	'CoreHome_ShortDay_3_js' => 'Tor',
	'CoreHome_ShortDay_4_js' => 'Sre',
	'CoreHome_ShortDay_5_js' => 'Čet',
	'CoreHome_ShortDay_6_js' => 'Pet',
	'CoreHome_ShortDay_7_js' => 'Sob',
	'CoreHome_LongDay_1_js' => 'Nedelja',
	'CoreHome_LongDay_2_js' => 'Ponedeljek',
	'CoreHome_LongDay_3_js' => 'Torek',
	'CoreHome_LongDay_4_js' => 'Sreda',
	'CoreHome_LongDay_5_js' => 'Četrtek',
	'CoreHome_LongDay_6_js' => 'Petek',
	'CoreHome_LongDay_7_js' => 'Sobota',
	'CoreHome_ShortMonth_1_js' => 'Jan',
	'CoreHome_ShortMonth_2_js' => 'Feb',
	'CoreHome_ShortMonth_3_js' => 'Mar',
	'CoreHome_ShortMonth_4_js' => 'Apr',
	'CoreHome_ShortMonth_5_js' => 'Maj',
	'CoreHome_ShortMonth_6_js' => 'Jun',
	'CoreHome_ShortMonth_7_js' => 'Jul',
	'CoreHome_ShortMonth_8_js' => 'Avg',
	'CoreHome_ShortMonth_9_js' => 'Sep',
	'CoreHome_ShortMonth_10_js' => 'Okt',
	'CoreHome_ShortMonth_11_js' => 'Nov',
	'CoreHome_ShortMonth_12_js' => 'Dec',
	'CoreHome_MonthJanuary_js' => 'Januar',
	'CoreHome_MonthFebruary_js' => 'Februar',
	'CoreHome_MonthMarch_js' => 'Marec',
	'CoreHome_MonthApril_js' => 'April',
	'CoreHome_MonthMay_js' => 'Maj',
	'CoreHome_MonthJune_js' => 'Junij',
	'CoreHome_MonthJuly_js' => 'Julij',
	'CoreHome_MonthAugust_js' => 'Avgust',
	'CoreHome_MonthSeptember_js' => 'September',
	'CoreHome_MonthOctober_js' => 'Oktober',
	'CoreHome_MonthNovember_js' => 'November',
	'CoreHome_MonthDecember_js' => 'December',
	'CorePluginsAdmin_Plugins' => 'Vtičniki',
	'CorePluginsAdmin_PluginsManagement' => 'Urejanje Vtičnikov',
	'CorePluginsAdmin_MainDescription' => 'Vtičniki razširjajo Piwik-ovo funkcionalnost. Ko je vtičnik enkrat nameščen, ga lahko tukaj aktivirate oziroma deaktivirate.',
	'CorePluginsAdmin_Plugin' => 'Vtičnik',
	'CorePluginsAdmin_Version' => 'Verzija',
	'CorePluginsAdmin_Status' => 'Status',
	'CorePluginsAdmin_Action' => 'Dejanje',
	'CorePluginsAdmin_AuthorHomepage' => 'Spletna stran avtorja',
	'CorePluginsAdmin_LicenseHomepage' => 'Spletna stran licence',
	'CorePluginsAdmin_PluginHomepage' => 'Spletna stran vtičnika',
	'CorePluginsAdmin_Activated' => 'Omogočeno',
	'CorePluginsAdmin_Active' => 'Aktivno',
	'CorePluginsAdmin_Inactive' => 'Neaktivno',
	'CorePluginsAdmin_Deactivate' => 'Onemogoči',
	'CorePluginsAdmin_Activate' => 'Omogoči',
	'CorePluginsAdmin_MenuPlugins' => 'Vtičniki',
	'CoreUpdater_PluginDescription' => 'Piwik-ov mehanizem za posodabljanje',
	'CoreUpdater_UpdateTitle' => 'Posodobitev',
	'CoreUpdater_DatabaseUpgradeRequired' => 'Potrebna je nadgraditev baze podatkov',
	'CoreUpdater_YourDatabaseIsOutOfDate' => 'Vaša baza podatkov je dotrajana. Preden lahko nadaljujete jo mora biti nadgrajena.',
	'CoreUpdater_PiwikWillBeUpgradedFromVersionXToVersionY' => 'Piwik-ova podatkovna baza bo nadgrajena iz različice %1$s, na novo različico %2$s.',
	'CoreUpdater_TheFollowingPluginsWillBeUpgradedX' => 'Sledeči vtičniki bodo posodobljeni: %s',
	'CoreUpdater_NoteForLargePiwikInstances' => 'Pomembna opomba za velike Piwik namestitve',
	'CoreUpdater_TheUpgradeProcessMayFailExecuteCommand' => 'V primeru, da ima vaša Piwik namestitev veliko bazo podatkov je mogoče, da posodabljanje v brskalniku traja zelo dolgo. V tem primeru lahko posodobitve uveljavite preko komandne vrstice: %s',
	'CoreUpdater_ClickHereToViewSqlQueries' => 'Kliknite tu, za ogled ter kopiranje seznama SQL proizvedb, ki bodo uveljavljene',
	'CoreUpdater_ReadyToGo' => 'Ste pripravljeni za začetek?',
	'CoreUpdater_TheUpgradeProcessMayTakeAWhilePleaseBePatient' => 'Proces nadgradnje podatkovne baze lahko traja nekaj časa, zato vas prosimo za potrpežljivost.',
	'CoreUpdater_UpgradePiwik' => 'Nadgradi Piwik',
	'CoreUpdater_UpgradeComplete' => 'Nadgradnja uspešno zaključena!',
	'CoreUpdater_WarningMessages' => 'Opozorila:',
	'CoreUpdater_ErrorDuringPluginsUpdates' => 'Napake, do katerih je prišlo med posodabljanjem vtičnikov:',
	'CoreUpdater_WeAutomaticallyDeactivatedTheFollowingPlugins' => 'Samodejno smo izklopili sledeče vtičnike: %s',
	'CoreUpdater_PiwikHasBeenSuccessfullyUpgraded' => 'Piwik je bil uspešno posodobljen!',
	'CoreUpdater_ContinueToPiwik' => 'Nadaljuj na Piwik',
	'CoreUpdater_UpdateAutomatically' => 'Samodejno posodpobi',
	'CoreUpdater_ThereIsNewVersionAvailableForUpdate' => 'Za posodobitev je na voljo nova različica Piwik-a',
	'CoreUpdater_YouCanUpgradeAutomaticallyOrDownloadPackage' => 'Sistem lahko na različico %s posodobite samodejno, ali pa prenesete paket, ter ga namestite ročno:',
	'CoreUpdater_DownloadX' => 'Prenos %s',
	'CoreUpdater_DownloadingUpdateFromX' => 'Prenašam posodobitev iz %s',
	'CoreUpdater_UnpackingTheUpdate' => 'Razpakiram posodobitev',
	'CoreUpdater_VerifyingUnpackedFiles' => 'Preverjam razpakirane datoteke',
	'CoreUpdater_CreatingBackupOfConfigurationFile' => 'Ustvarjam varnostno kopijo konfiguracijske datoteke v %s',
	'CoreUpdater_InstallingTheLatestVersion' => 'Nameščanje najnovejše različice',
	'CoreUpdater_PiwikUpdatedSuccessfully' => 'Piwik je bil uspešno posodobljen!',
	'CoreUpdater_EmptyDatabaseError' => 'Baza podatkov %s je prazna. Urediti ali pa odstraniti morate vašo Piwik-ovo konfiguracijsko datoteko.',
	'CoreUpdater_ExceptionAlreadyLatestVersion' => 'Imate najnovejšo verzijo Piwik-a (%s)',
	'CoreUpdater_ExceptionArchiveIncompatible' => 'Nezdružljiv arhic: %s',
	'CoreUpdater_ExceptionArchiveEmpty' => 'Prazen arhiv.',
	'CoreUpdater_ExceptionArchiveIncomplete' => 'Arhiv je nepopoln: manjkajo nekatere datoteke (npr. %s).',
	'Dashboard_PluginDescription' => 'Nadzorna plošča vaše spletne analitike. Nadzorno ploščo lahko prilagajate: dodajate nove gradnike, spreminjate njihov vrstni red. Vsak uporabnik lahko dostopa do svoje lastne kontrolne plošče.',
	'Dashboard_Dashboard' => 'Nadzorna Plošča',
	'Dashboard_AddAWidget' => 'Dodaj gradnik',
	'Dashboard_DeleteWidgetConfirm' => 'Ste prepričani da želite izbrisati ta gradnik s kontrolne plošče?',
	'Dashboard_SelectWidget' => 'Izberite gradnik, ki ga želite dodati na kontrolno ploščo.',
	'Dashboard_AddPreviewedWidget_js' => 'Kliknite, če želite dodati gradnik na kontrolno ploščo',
	'Dashboard_WidgetPreview_js' => 'Predogled gradnika',
	'Dashboard_Close_js' => 'Zapri',
	'Dashboard_Refresh_js' => 'Osveži',
	'Dashboard_Maximise_js' => 'Povečaj',
	'Dashboard_Minimise_js' => 'Pomanjšaj',
	'Dashboard_TitleWidgetInDashboard_js' => 'Gradnik je že na v kontrolni plošči',
	'Dashboard_TitleClickToAdd_js' => 'Kliknite, če želite dodati na nadzorno ploščo',
	'Dashboard_LoadingWidget_js' => 'Nalagam gradnik...',
	'Dashboard_WidgetNotFound_js' => 'Gradnik ni bil najden',
	'Dashboard_ResetDashboard' => 'Ponastavi kontrolno ploščo',
	'Dashboard_ResetDashboardConfirm' => 'Ste prepričani da želite ponastaviti postavitev kontrolne plošče na privzeti izbor gradnikov?',
	'Dashboard_WidgetsAndDashboard' => 'Gradniki & Kontrolna Plošča',
	'Dashboard_ChangeDashboardLayout' => 'Spremeni postavitev nadzorne plošče',
	'Dashboard_SelectDashboardLayout' => 'Prosimo, izberite vašo novo postavitev nadzorne plošče',
	'DBStats_PluginDescription' => 'Ta vtičnik poroča o Piwik-ovi uporabi MySQL podatkovne baze.',
	'DBStats_DatabaseUsage' => 'Uporaba podatkovne baze',
	'DBStats_MainDescription' => 'Piwik shranjuje vse vaše podatke v MySQL bazo podatkov. Trenutna poraba podatkovne baze je %s.',
	'DBStats_Table' => 'Tabela',
	'DBStats_RowCount' => 'Število vrst',
	'DBStats_DataSize' => 'Velikost podatkov',
	'DBStats_IndexSize' => 'Velikost indeksa',
	'DBStats_TotalSize' => 'Skupna velikost',
	'ExampleAPI_PluginDescription' => 'Primer Vtičnika: Kako ustvariti API za vaš vtičnik za izvažanje vaših podatkov v večih formatih, brez posebnega programiranja.',
	'Feedback_PluginDescription' => 'Podajte vašo povratno informacijo ekipi Piwik. Zaupajte nam vaše ideje in predloge!',
	'Feedback_DoYouHaveBugReportOrFeatureRequest' => 'Imate napako ali pa željo, ki nam jo želite sporočiti?',
	'Feedback_ViewAnswersToFAQ' => 'Oglejte si odgovore na %sPogosto Zastavljena Vprašanja (FAQ)%s',
	'Feedback_WhyAreMyVisitsNoTracked' => 'Zakaj niso obiskovalci moje spletne strani sledeni?',
	'Feedback_HowToExclude' => 'Kako izključim sledenje mojih obiskov?',
	'Feedback_WhyWrongCountry' => 'Zakaj Piwik prikazuje moje obiske iz napačne države?',
	'Feedback_VisitTheForums' => 'Obiščite %sForume%s',
	'Feedback_LearnWaysToParticipate' => 'Oglejte si vse načine kako lahko %ssodelujete%s',
	'Feedback_ContactThePiwikTeam' => 'Kontaktiraje Piwik-ovo ekipo!',
	'Feedback_IWantTo' => 'Želim:',
	'Feedback_CategoryShareStory' => 'Delite Piwik zgodbo o uspehu',
	'Feedback_CategorySponsor' => 'Sponzorirajte Piwik',
	'Feedback_CategoryHire' => 'Najemite Piwiki-svetovalca',
	'Feedback_CategorySecurity' => 'Prijavi varnostno napako',
	'Feedback_MyEmailAddress' => 'Moj email:',
	'Feedback_MyMessage' => 'Moje sporočilo:',
	'Feedback_DetailsPlease' => '(prosimu vključite podrobnosti)',
	'Feedback_SendFeedback' => 'Pošlji povratno informacijo',
	'Feedback_ManuallySendEmailTo' => 'Prosimo, da sporočilo ročno pošljete',
	'Feedback_MessageSent' => 'Vaše sporočilo je bilo poslano Piwik-ovi ekipi.',
	'Feedback_ThankYou' => 'Hvala, ker nam pomagate izboljšati Piwik!',
	'Feedback_ThePiwikTeam' => 'Piwik-ova ekipa',
	'Feedback_ExceptionBodyLength' => 'Sporočilo mora biti dolgo vsaj %s znakov.',
	'Feedback_ExceptionNoUrls' => 'Sporočilo ne sme vsebovati URL-ja, da ne bo padlo pod vsiljeno pošto.',
	'Goals_Goals' => 'Cilji',
	'Goals_Ecommerce' => 'Ecommerce',
	'Goals_EcommerceOverview' => 'Ecommerce pregled',
	'Goals_EcommerceLog' => 'Ecommerce zgodovina',
	'Goals_AbandonedCart' => 'Opuščen voziček',
	'Goals_GoalsOverview' => 'Pregled ciljev',
	'Goals_GoalsManagement' => 'Upravljanje ciljev',
	'Goals_ColumnRevenue' => 'Prihodki',
	'Goals_GoalX' => 'Cilj %s',
	'Goals_GoalConversion' => 'Spreobrnitev cilja',
	'Goals_GoalConversions' => 'Spreobrnitve ciljev',
	'Goals_AddGoal_js' => 'Dodaj Cilj',
	'Goals_UpdateGoal_js' => 'Posodobi Cilj',
	'Goals_DeleteGoalConfirm_js' => 'Ste prepričani de želite izbrisati Cilj%s?',
	'Goals_CreateNewGOal' => 'Ustvarite nov Cilj',
	'Goals_GoalName' => 'Ime Cilja',
	'Goals_WhenVisitors' => 'ko obiskovalci',
	'Goals_Manually' => 'ročno',
	'Goals_URL' => 'URL',
	'Goals_PageTitle' => 'Naslov strani',
	'Goals_Filename' => 'ime datoteke',
	'Goals_Download' => 'Prenesite datoteko',
	'Goals_Optional' => '(opcijsko)',
	'Goals_ConversionsOverview' => 'Pregled sprememb',
	'Goals_Contains' => 'vsebuje %s',
	'Goals_IsExactly' => 'je točno %s',
	'Goals_MatchesExpression' => 'se ujema z nizom %s',
	'Goals_Pattern' => 'Vzorec',
	'Goals_ProductSKU' => 'SKU izdelka',
	'Goals_ProductName' => 'Ime izdelka',
	'Goals_ProductCategory' => 'Kategorija izdelkov',
	'Goals_Products' => 'Izdelki',
	'Goals_VisitsUntilConv' => 'Obiskov za spreobrnitev',
	'Goals_DaysToConv' => 'Dni za spreobrnitev',
	'Installation_Installation' => 'Namestitev',
	'Installation_InstallationStatus' => 'Status namestitve',
	'Installation_PercentDone' => '%s %% Končano',
	'Installation_DatabaseSetupServer' => 'strežnik podatkovne baze',
	'Installation_DatabaseSetupLogin' => 'vpis',
	'Installation_DatabaseSetupPassword' => 'geslo',
	'Installation_DatabaseSetupDatabaseName' => 'ime podatkovne baze',
	'Installation_DatabaseServerVersion' => 'Verzija strežnika podatkovne baze',
	'Installation_PleaseFixTheFollowingErrors' => 'Prosimo, odpravite sledeče napake',
	'Installation_JsTag' => 'JavaScript sledilna koda',
	'Installation_Congratulations' => 'Čestitamo',
	'Installation_CongratulationsHelp' => '<p>Čestitamo! Namestitev Piwik-a je končana.</p><p>Poskrbite, da bo JavaScript sledilna koda integrirana v željene strani</p>',
	'Installation_ContinueToPiwik' => 'Nadaljuj na Piwik',
	'Installation_SetupWebsite' => 'Nastavite spletno stran',
	'Installation_SetupWebSiteName' => 'ime spletne strani',
	'Installation_SetupWebSiteURL' => 'URL spletne strani',
	'Installation_Timezone' => 'časovni pas spletne strani',
	'Installation_SetupWebsiteError' => 'Med dodajanjem spletne strani je prišlo do napake.',
	'Installation_SetupWebsiteSetupSuccess' => 'Spletna stran %s je bila uspešno ustvarjena!',
	'Installation_SuperUser' => 'Super Uporabnik',
	'Installation_SuperUserSetupSuccess' => 'Super Uporabnik je bil uspešno ustvarjen',
	'Installation_SuperUserLogin' => 'vpis super uporabnika',
	'Installation_Password' => 'geslo',
	'Installation_PasswordRepeat' => 'geslo (ponovno)',
	'Installation_Email' => 'email',
	'Installation_SecurityNewsletter' => 'obveščajte me o najpomembnejših varnostnih opozorilh Piwik-a',
	'Installation_PasswordDoNotMatch' => 'gesli se ne ujemata',
	'Installation_Requirements' => 'Piwik-ovi minimalni pogoji',
	'Installation_Optional' => 'Izbirno',
	'Installation_Legend' => 'Legenda',
	'Installation_Extension' => 'razširitev',
	'Installation_SystemCheckPhp' => 'PHP verzija',
	'Installation_SystemCheckExtensions' => 'Ostale potrebne razširitve',
	'Installation_TablesCreatedSuccess' => 'Tabele so bile uspešno ustvarjene!',
	'Installation_Welcome' => 'Dobrodošli!',
	'LanguagesManager_PluginDescription' => 'Ta vtičnik bo prikazoval seznam vseh jezikov, ki so na voljo za Piwik-ov vmesnik. Izbrani jezik bo shranjen v nastavitvah vsakega uporabnika.',
	'LanguagesManager_AboutPiwikTranslations' => 'O prevodih Piwik-a',
	'Live_PluginDescription' => 'Opazujte vaše obiskovalce v živo!',
	'Live_LinkVisitorLog' => 'Ogled podrobnega dnevnika obiskovalcev',
	'Live_Actions' => 'Dejanja',
	'Live_Action' => 'Dejanje',
	'Live_VisitorsInRealTime' => 'Obiskovalci v živo',
	'Live_VisitorLog' => 'Dnevnik obiskovalcev',
	'Live_Time' => 'Čas',
	'Live_LastMinutes' => 'Zadnjih %s minutah',
	'Live_LastHours' => 'Zadnjih %s urah',
	'Live_GoalType' => 'Tip',
	'Live_GoalDetails' => 'Podrobnosti',
	'Live_VisitorsLastVisit' => 'Zadnji obisk tega obiskovalce je bil pred %s dnevi.',
	'Login_Password' => 'Geslo',
	'Login_PasswordRepeat' => 'Geslo (ponovno)',
	'Login_ChangePassword' => 'Spremeni geslo',
	'Login_LoginOrEmail' => 'Uporabniško ime ali E-mail',
	'Login_RememberMe' => 'Zapomni si me',
	'Login_LogIn' => 'Vpis',
	'Login_Logout' => 'Izpis',
	'Login_LostYourPassword' => 'Ste pozabili geslo?',
	'Login_PasswordsDoNotMatch' => 'Gesli se ne ujemata.',
	'Mobile_LastUpdated' => 'Zadnje posodobljeno: %s',
	'Mobile_PullDownToRefresh' => 'Potegnite navzdol za osvežitev...',
	'Mobile_Refresh' => 'Osveži',
	'Mobile_Reloading' => 'Nalagam...',
	'Mobile_ReleaseToRefresh' => 'Izpustite za osvežitev...',
	'Mobile_ShowAll' => 'Prikaži vse',
	'Mobile_ShowLess' => 'Prikaži manj',
	'Mobile_AnonymousAccess' => 'Anonimni dostop',
	'Mobile_AccessUrlLabel' => 'Piwik dostopni URL',
	'Mobile_EnableGraphsLabel' => 'Prikaži grafe',
	'Mobile_DefaultReportDate' => 'Datum poročila',
	'Mobile_NavigationBack' => 'Nazaj',
	'Mobile_SaveSuccessError' => 'Prosimo, zagotovite nastavitve',
	'Mobile_YouAreOffline' => 'Oprostite, trenutno ste offline',
	'MultiSites_Evolution' => 'Evolucija',
	'Provider_WidgetProviders' => 'Ponudniki',
	'Provider_ColumnProvider' => 'Ponudnik',
	'Provider_SubmenuLocationsProvider' => 'Lokacije & Ponudnik',
	'Referers_SearchEngines' => 'Spletni Iskalniki',
	'Referers_Keywords' => 'Ključne Besede',
	'Referers_Websites' => 'Spletne Strani',
	'Referers_Campaigns' => 'Kampanje',
	'Referers_ColumnSearchEngine' => 'Spletni Iskalnik',
	'Referers_ColumnWebsite' => 'Spletna Stran',
	'Referers_ColumnWebsitePage' => 'Spletna stran',
	'Referers_ColumnKeyword' => 'Ključna Beseda',
	'Referers_ColumnCampaign' => 'Kampanja',
	'Referers_DistinctSearchEngines' => 'različni brskalniki',
	'Referers_DistinctKeywords' => 'različne ključne besede',
	'Referers_DistinctCampaigns' => 'različne kampanje',
	'Referers_DistinctWebsites' => 'različne spletne strani',
	'Referers_SubmenuOverview' => 'Pregled',
	'Referers_SubmenuSearchEngines' => 'Brskalniki & ključne besede',
	'Referers_SubmenuWebsites' => 'Spletne strani',
	'Referers_SubmenuCampaigns' => 'Kampanje',
	'Referers_WidgetKeywords' => 'Seznam ključnih besed',
	'Referers_WidgetCampaigns' => 'Seznam kampanij',
	'Referers_WidgetExternalWebsites' => 'Seznam zunanjih spletnih strani',
	'Referers_WidgetSearchEngines' => 'Najboljši spletni iskalniki',
	'Referers_WidgetOverview' => 'Pregled',
	'SecurityInfo_Security' => 'Varnost',
	'SecurityInfo_SecurityInformation' => 'PHP varnostni podatki',
	'SecurityInfo_Test' => 'Test',
	'SecurityInfo_Result' => 'Rezultat',
	'SEO_SeoRankings' => 'SEO položaji',
	'SEO_AlexaRank' => 'Alexa položaj',
	'SEO_DomainAge' => 'Starost domene',
	'SEO_Rank' => 'Položaj',
	'SEO_Pages' => 'Strani',
	'SitesManager_Sites' => 'Spletne strani',
	'SitesManager_TrackingTags' => 'Sledilna koda za %s',
	'SitesManager_WebsitesManagement' => 'Upravljanje spletnih strani',
	'SitesManager_OnlyOneSiteAtTime_js' => 'Sočasno lahko urejate zgolj eno spletno stran. Prosimo, shranite ali pa prekličite vaše trenutne spremembe za spletno stran %s.',
	'SitesManager_JsTrackingTag' => 'JavaScript sledilna koda',
	'SitesManager_JsTrackingTagHelp' => 'Tu je JavaScript sledilna koda, ki jo vključite v vse vaše strani',
	'SitesManager_ShowTrackingTag' => 'Oglej si sledilno kodo',
	'SitesManager_NoWebsites' => 'Nimate spletnih strani za urejanje',
	'SitesManager_AddSite' => 'Dodaj novo spletno stran',
	'SitesManager_NotFound' => 'Ni bilo najdenih spletnih strani za',
	'SitesManager_Urls' => 'Povezave',
	'SitesManager_MenuSites' => 'Spletne strani',
	'SitesManager_DeleteConfirm_js' => 'Ste prepričani da želite izbrisati spletno stran %s?',
	'SitesManager_ExceptionDeleteSite' => 'Te spletne strani ni mogoče izbrisati, saj je trenutno edina registrirana spletna stran. Šele ko boste dodali novo spletno stran, boste lahko izbrisali to spletno stran.',
	'SitesManager_ExceptionNoUrl' => 'Navesti morate vsaj en URL za to spletno stran.',
	'SitesManager_ExceptionEmptyName' => 'Ime spletne strani ne sme biti prazno.',
	'SitesManager_ExceptionInvalidUrl' => 'Vnešeni URL "%s" ni veljaven.',
	'SitesManager_ExceptionInvalidTimezone' => 'Časovno območje "%s" ni veljavno. Prosimo, vnesite veljavno časovno območje.',
	'SitesManager_ExcludedIps' => 'Izključeni IP naslovi',
	'SitesManager_ListOfIpsToBeExcludedOnAllWebsites' => 'Spodnji IP-ji bodo izključeni iz sledenja na vseh spletnih straneh.',
	'SitesManager_ExcludedParameters' => 'Izključeni Parametri',
	'SitesManager_YourCurrentIpAddressIs' => 'Vaš trenuten IP je %s',
	'SitesManager_SelectACity' => 'Izberite mesto',
	'SitesManager_ChooseCityInSameTimezoneAsYou' => 'Izberite mesto, ki je v istem časovnem pasu kot vi.',
	'SitesManager_UTCTimeIs' => 'UTC čas je %s.',
	'SitesManager_Timezone' => 'Časovno območje',
	'SitesManager_DefaultTimezoneForNewWebsites' => 'Privzet časovni pas za nove spletne strani',
	'SitesManager_Currency' => 'Valuta',
	'SitesManager_DefaultCurrencyForNewWebsites' => 'Privzeta Valuta za nove spletne strani',
	'SitesManager_SelectDefaultCurrency' => 'Izberete lahko privzeto valuto. Ta bo uporabljena na vseh novo-dodanih spletnih straneh.',
	'SitesManager_EnableEcommerce' => 'Ecommerce omogočen',
	'TranslationsAdmin_PluginDescription' => 'Pomagajte nam prevesti Piwik v vaš jezik.',
	'TranslationsAdmin_MenuTranslations' => 'Prevodi',
	'TranslationsAdmin_MenuLanguages' => 'Jeziki',
	'TranslationsAdmin_LanguageCode' => 'Šifra jezika',
	'TranslationsAdmin_Plugin' => 'Vtičnik',
	'TranslationsAdmin_Definition' => 'Definicija',
	'TranslationsAdmin_Translations' => 'Prevodi',
	'TranslationsAdmin_AddLanguage' => 'Dodaj jezik',
	'TranslationsAdmin_Export' => 'Izvozi jezik',
	'TranslationsAdmin_Import' => 'Uvozi jezik',
	'TranslationsAdmin_ShowOnlyEmpty' => 'Prikaži samo manjkajoče prevode',
	'TranslationsAdmin_TranslationAlreadyExists' => 'Prevod že obstaja',
	'TranslationsAdmin_CannotOpenForWriting' => 'Ne morem odpreti %s za zapisovanje',
	'TranslationsAdmin_InvalidCountry' => 'Napačna država',
	'TranslationsAdmin_InvalidLanguage' => 'Napačen jezik',
	'UserCountry_PluginDescription' => 'Sporoči državo, iz katere so obiskovalci.',
	'UserCountry_Country' => 'Država',
	'UserCountry_Continent' => 'Kontitent',
	'UserCountry_Location' => 'Lokacija',
	'UserCountry_SubmenuLocations' => 'Lokacije',
	'UserCountry_country_ad' => 'Andora',
	'UserCountry_country_al' => 'Albanija',
	'UserCountry_country_ar' => 'Argentina',
	'UserCountry_country_at' => 'Avstrija',
	'UserCountry_country_au' => 'Avstralija',
	'UserCountry_country_ba' => 'Bosna in Hercegovina',
	'UserCountry_country_be' => 'Belgija',
	'UserCountry_country_bf' => 'Burkina Faso',
	'UserCountry_country_br' => 'Brazilija',
	'UserCountry_country_by' => 'Belorusija',
	'UserCountry_country_ca' => 'Kanada',
	'UserCountry_country_cg' => 'Kongo',
	'UserCountry_country_ch' => 'Švica',
	'UserCountry_country_cl' => 'Čile',
	'UserCountry_country_cn' => 'Kitajska',
	'UserCountry_country_cu' => 'Kuba',
	'UserCountry_country_cy' => 'Ciper',
	'UserCountry_country_de' => 'Nemčija',
	'UserCountry_country_eg' => 'Egipt',
	'UserCountry_country_es' => 'Španija',
	'UserCountry_country_et' => 'Etiopija',
	'UserCountry_country_eu' => 'Evropska Unija',
	'UserCountry_country_fi' => 'Finska',
	'UserCountry_country_fj' => 'Fiji',
	'UserCountry_country_fr' => 'Francija',
	'UserCountry_country_gr' => 'Grčija',
	'UserCountry_country_hk' => 'Hong Kong',
	'UserCountry_country_hr' => 'Hrvaška',
	'UserCountry_country_ht' => 'Haiti',
	'UserCountry_country_hu' => 'Madžarska',
	'UserCountry_country_id' => 'Indonezija',
	'UserCountry_country_ie' => 'Irska',
	'UserCountry_country_il' => 'Izrael',
	'UserCountry_country_in' => 'Indija',
	'UserCountry_country_iq' => 'Irak',
	'UserCountry_country_ir' => 'Iran',
	'UserCountry_country_is' => 'Islandija',
	'UserCountry_country_it' => 'Italija',
	'UserCountry_country_jm' => 'Jamajka',
	'UserCountry_country_jp' => 'Japonska',
	'UserCountry_country_lt' => 'Litva',
	'UserCountry_country_lu' => 'Luksemburg',
	'UserCountry_country_lv' => 'Matvija',
	'UserCountry_country_mc' => 'Monako',
	'UserCountry_country_me' => 'Montenegro',
	'UserCountry_country_mg' => 'Madagaskar',
	'UserCountry_country_mk' => 'Makedonija',
	'UserCountry_country_ml' => 'Mali',
	'UserCountry_country_mn' => 'Mongolija',
	'UserCountry_country_mt' => 'Malta',
	'UserCountry_country_mv' => 'Maldivi',
	'UserCountry_country_mx' => 'Mehika',
	'UserCountry_country_nc' => 'Nova Kaledonija',
	'UserCountry_country_ne' => 'Niger',
	'UserCountry_country_ng' => 'Nigerija',
	'UserCountry_country_nl' => 'Nizozemska',
	'UserCountry_country_no' => 'Norveška',
	'UserCountry_country_np' => 'Nepal',
	'UserCountry_country_nz' => 'Nova Zelandija',
	'UserCountry_country_pe' => 'Peru',
	'UserCountry_country_pt' => 'Portugalska',
	'UserCountry_country_rs' => 'Srbija',
	'UserCountry_country_se' => 'Švedska',
	'UserCountry_country_sf' => 'Finska',
	'UserCountry_country_si' => 'Slovenija',
	'UserCountry_country_sk' => 'Slovaška',
	'UserCountry_country_th' => 'Tajska',
	'UserCountry_country_tr' => 'Turčija',
	'UserCountry_country_tw' => 'Tajvan',
	'UserCountry_country_ua' => 'Ukrajina',
	'UserCountry_country_uk' => 'Združeno kraljestvo',
	'UserCountry_country_us' => 'Združene države',
	'UserCountry_country_uy' => 'Urugvaj',
	'UserCountry_country_uz' => 'Uzbekistan',
	'UserCountry_country_vn' => 'Vietnam',
	'UserCountry_country_ws' => 'Samoa',
	'UserCountry_country_yt' => 'Mayotte',
	'UserCountry_country_yu' => 'Jugoslavija',
	'UserCountry_country_za' => 'Južna Afrika',
	'UserCountry_country_zw' => 'Zimbabve',
	'UserCountry_country_a1' => 'Anonimen Proxy',
	'UserCountry_country_ap' => 'Azija/Pacifiška regija',
	'UserCountry_country_o1' => 'Druge države',
	'UserCountry_continent_eur' => 'Evropa',
	'UserCountry_continent_afr' => 'Afrika',
	'UserCountry_continent_ant' => 'Antartika',
	'UserCountry_continent_asi' => 'Azija',
	'UserCountry_continent_amn' => 'Severna Amerika',
	'UserCountry_continent_amc' => 'Sredjna Amerika',
	'UserCountry_continent_ams' => 'Južna Amerika',
	'UserCountry_continent_oce' => 'Oceanija',
	'UserCountryMap_map' => 'zemljevid',
	'UserCountryMap_worldMap' => 'svetovni zemljevid',
	'UserCountryMap_toggleFullscreen' => 'Celozaslonski Način',
	'UserSettings_VisitorSettings' => 'Nastavitve Obiskovalcev',
	'UserSettings_BrowserFamilies' => 'Družine brskalnikov',
	'UserSettings_Browsers' => 'Brskalniki',
	'UserSettings_Plugins' => 'Vtičniki',
	'UserSettings_Configurations' => 'Nastavitve',
	'UserSettings_OperatingSystems' => 'Operacijski sistemi',
	'UserSettings_Resolutions' => 'Resolucije',
	'UserSettings_WideScreen' => 'Širok Zaslon',
	'UserSettings_ColumnBrowser' => 'Brskalnik',
	'UserSettings_ColumnBrowserVersion' => 'Verzija Brskalnika',
	'UserSettings_ColumnPlugin' => 'Vtičnik',
	'UserSettings_ColumnConfiguration' => 'Nastavitev',
	'UserSettings_ColumnOperatingSystem' => 'Operacijski sistem',
	'UserSettings_ColumnResolution' => 'Resolucija',
	'UserSettings_ColumnTypeOfScreen' => 'Tip zaslona',
	'UserSettings_WidgetResolutions' => 'Resolucija zaslona',
	'UserSettings_WidgetPlugins' => 'Seznam Vtičnikov',
	'UserSettings_WidgetBrowserFamilies' => 'Brskalniki po družini',
	'UserSettings_WidgetOperatingSystems' => 'Operacijski sistemi',
	'UserSettings_SubmenuSettings' => 'Nastavitve',
	'UsersManager_UsersManagement' => 'Upravljanje Uporabnikov',
	'UsersManager_ThereAreCurrentlyNRegisteredUsers' => 'Trenutno je %s registriranih uporabnikov.',
	'UsersManager_ManageAccess' => 'Upravljaj dostop',
	'UsersManager_Sites' => 'Spletne strani',
	'UsersManager_AllWebsites' => 'Vse spletne strani',
	'UsersManager_ApplyToAllWebsites' => 'Uveljavi za vse spletne strani',
	'UsersManager_User' => 'Uporabnik',
	'UsersManager_PrivNone' => 'Ni dostopa',
	'UsersManager_PrivView' => 'Pogled',
	'UsersManager_PrivAdmin' => 'Admin',
	'UsersManager_Password' => 'Geslo',
	'UsersManager_Email' => 'Email',
	'UsersManager_Alias' => 'Psevdonim',
	'UsersManager_Edit' => 'Uredi',
	'UsersManager_AddUser' => 'Dodaj novega uporabnika',
	'UsersManager_MenuUsers' => 'Uporabniki',
	'UsersManager_MenuUserSettings' => 'Nastavitve uporabnikov',
	'UsersManager_MenuAnonymousUserSettings' => 'Nastavitve anonimnih uporabnikov',
	'UsersManager_ChangePassword' => 'Spremeni geslo',
	'UsersManager_IfYouWouldLikeToChangeThePasswordTypeANewOne' => 'Če bi radi spremenili geslo, vpišite novega. Če ne, to pustite prazno.',
	'UsersManager_TypeYourPasswordAgain' => 'Ponovno vpišite vaše novo geslo.',
	'UsersManager_TheLoginScreen' => 'Obrazec za vpis',
	'UsersManager_DeleteConfirm_js' => 'Ste prepričani, da želite izbrisati uporabnika %s?',
	'UsersManager_YourUsernameCannotBeChanged' => 'Vaše uporabniško ime ne more biti spremenjeno.',
	'UsersManager_ExceptionLoginExists' => 'Vpis \'%s\' že obstaja.',
	'UsersManager_ExceptionEmailExists' => 'Uporabnik z emailom "%s" že obstaja.',
	'UsersManager_ExceptionInvalidPassword' => 'Dolžina gesla mora biti med %1$s in %2$s znaki.',
	'UsersManager_ExceptionInvalidEmail' => 'Email ni veljavnega formata.',
	'UsersManager_ExceptionDeleteDoesNotExist' => 'Uporabnik \'%s\' ne obstaja, ter ga tako ni moč izbrisati.',
	'UsersManager_ExceptionAdminAnonymous' => '"Anonimnemu" uporabniku ne morate dodeliti administrativnih dovoljenj.',
	'UsersManager_ExceptionUserDoesNotExist' => 'Uporabnik "%s" ne obstaja.',
	'VisitFrequency_WidgetOverview' => 'Frekvenčni pregled',
	'VisitFrequency_SubmenuFrequency' => 'Frekvenca',
	'VisitorGenerator_PluginDescription' => 'Vtičnik za ustvarjanje navideznih obiskov. Tega lahko uporabljajo uporabniki ali pa razvijalci, ter tako generirajo lažne podatke in z njimi napolnijo Piwik-ova poročila.',
	'VisitorGenerator_VisitorGenerator' => 'Generator Obiskovalcev',
	'VisitorGenerator_Warning' => 'Ravnokar boste generirali navidezne obiske, ki bodo shranjeni v podatkovno bazo vašega sistema Piwik.',
	'VisitorGenerator_AreYouSure' => 'Ste prepričani, da želite generirate navidezne obiske?',
	'VisitorGenerator_ChoiceYes' => 'Da, prepričan sem!',
	'VisitorGenerator_Submit' => 'Uveljavi',
	'VisitorGenerator_SelectWebsite' => 'Izberi spletno stran',
	'VisitorGenerator_NbRequestsPerSec' => 'Zahtev na sekundo',
	'VisitorInterest_VisitsPerNbOfPages' => 'Obiskov na število strani',
	'VisitorInterest_ColumnVisitDuration' => 'Trajanje obiska',
	'VisitorInterest_ColumnPagesPerVisit' => 'Strani na obisk',
	'VisitorInterest_VisitNum' => 'Številka obiska',
	'VisitorInterest_WidgetLengths' => 'Dolžina obiskov',
	'VisitorInterest_WidgetPages' => 'Strani na obisk',
	'VisitorInterest_OneMinute' => '1 min',
	'VisitorInterest_PlusXMin' => '%s min',
	'VisitorInterest_OnePage' => '1 stran',
	'VisitorInterest_NPages' => '%s strani',
	'VisitsSummary_PluginDescription' => 'Prikaže splošne statistike glede obiska na spletni strani: obiske, unikatne obiske, število akcij, odbojno stopnjo, itd.',
	'VisitsSummary_VisitsSummary' => 'Povzetek obiskov',
	'VisitsSummary_VisitsSummaryDocumentation' => 'To je pregled obiskov v zadnjem času.',
	'VisitsSummary_NbVisits' => '%s obiskov',
	'VisitsSummary_NbUniqueVisitors' => '%s unikatnih obiskovalcev',
	'VisitsSummary_NbActionsDescription' => '%s akcij',
	'VisitsSummary_NbPageviewsDescription' => '%s ogledov',
	'VisitsSummary_NbUniquePageviewsDescription' => '%s unikatnih ogledov',
	'VisitsSummary_NbDownloadsDescription' => '%s prenosov',
	'VisitsSummary_NbUniqueDownloadsDescription' => '%s unikatnih prenosov',
	'VisitsSummary_NbOutlinksDescription' => '%s izhodnih povezav',
	'VisitsSummary_NbUniqueOutlinksDescription' => '%s unikatnih izhodnih povezav',
	'VisitsSummary_AverageVisitDuration' => '%s povprečno trajanje obiska',
	'VisitsSummary_MaxNbActions' => '%s največje število akcij v enem obisku',
	'VisitsSummary_NbActionsPerVisit' => '%s akcij (ogledov, prenosov, izhodnih povezav) na obisk',
	'VisitsSummary_NbVisitsBounced' => '%s ogledov je bilo odbojev (so zapustili stran po ogledu ene strani)',
	'VisitsSummary_GenerateTime' => '%s sekund za prikaz strani',
	'VisitsSummary_GenerateQueries' => '%s ukazov izvršenih',
	'VisitsSummary_WidgetLastVisits' => 'Graf zadnjih obiskov',
	'VisitsSummary_WidgetVisits' => 'Povzetek obiskov',
	'VisitsSummary_WidgetLastVisitors' => 'Graf zadnjih unikatnih obiskov',
	'VisitsSummary_WidgetOverviewGraph' => 'Pregled z grafom',
	'VisitsSummary_SubmenuOverview' => 'Pregled',
	'VisitTime_LocalTime' => 'Obiski na lokalni čas',
	'VisitTime_ServerTime' => 'Obiski na čas strežnika',
	'VisitTime_ColumnServerTime' => 'Čas na strežniku',
	'VisitTime_ColumnLocalTime' => 'Lokalni čas',
	'VisitTime_WidgetLocalTime' => 'Obiski glede na lokalni čas',
	'VisitTime_WidgetServerTime' => 'Obiski glede na čas na strežniku',
	'VisitTime_SubmenuTimes' => 'Časi',
	'VisitTime_NHour' => '%sh',
	'PDFReports_ManageEmailReports' => 'Urejaj Email Poročila',
	'PDFReports_EmailReports' => 'Email Poročila',
	'PDFReports_PDF' => 'PDF',
	'PDFReports_SendReportNow' => 'Pošlji Poročilo zdaj',
	'PDFReports_EmailSchedule' => 'Urnik Emailov',
	'PDFReports_SendReportTo' => 'Pošlji poročilo k',
	'PDFReports_ReportFormat' => 'Format poročila',
	'PDFReports_AggregateReportsFormat' => '(opcijsko) Opcije prikaza',
	'PDFReports_SentToMe' => 'Pošlji meni',
	'PDFReports_WeeklyScheduleHelp' => 'Mesečno poročilo: poročilo bo poslano vsak ponedeljek.',
	'PDFReports_MonthlyScheduleHelp' => 'Mesečno poročilo: poročilo bo poslano vsak prvi dan v mesecu.',
	'PDFReports_AlsoSendReportToTheseEmails' => 'Poročila pošlji tudi na sledeče emaile (en email v vsako vrstico):',
	'PDFReports_ReportsIncluded' => 'Statistika vključena',
	'PDFReports_CreateReport' => 'Ustvari poročilo',
	'PDFReports_UpdateReport' => 'Posodobi poročilo',
	'PDFReports_PiwikReports' => 'Piwik Poročila',
	'PDFReports_EmailHello' => 'Zdravo,',
	'PDFReports_AreYouSureDeleteReport' => 'Ste prepričani, da želite izbrisati to poročilo in urnik?',
	'PDFReports_FrontPage' => 'Prva Stran',
	'PDFReports_TableOfContent' => 'Seznam poročil',
	'PDFReports_TopOfReport' => 'Nazaj na vrh',
	'PDFReports_Pagination' => 'Stran %s od %s',
	'ImageGraph_PluginDescription' => 'Ustvarite prelepe, statične, PNG grafe za vsa Piwik poročila.',

	// FOR REVIEW
	'Forecast_Actions' => 'Obiski strani',
	'Forecast_Column' => 'Napoved',
	'GeoIP_ColumnCity' => 'Mesto',
	'GeoIP_Continent' => 'Kontinent',
	'GeoIP_Country' => 'Država',
	'GeoIP_DistinctCountries' => '%s različnih držav',
	'GeoIP_SubmenuLocations' => 'Kraji',
	'GeoIP_WidgetContinents' => 'Kontinenti obiskovalcev',
	'GeoIP_WidgetCountries' => 'Države obiskovalcev',
);
